#ifndef COM_H
#define COM_H

/*! \brief Initialize the serial communication struct
 */
void comInit();

/*! \brief Set the read timeout
 * \param args string with deci second value for Timeout
 * \return `true` if value could be parsed and set
 */
bool comTimeout(const char * args);

/*! \brief Set the baud rate
 * \param args string with baud rate (300 - 115200)
 * \return `true` if value could be parsed and set
 */
bool comBaudrate(const char * args);

/*! \brief Specify to communication settings
 * \param args string with data bits, parity and stop bits
 * \return `true` if values could be parsed and set
 */
bool comSettings(const char * args);

/*! \brief Establish connection
 * \param device path to serial device
 * \return `true` if connection could be established
 */
bool comConnect(const char * device);

/*! \brief Receive a character from the device
 * \return received character
 */
char comReceive();

/*! \brief Send a character to the device
 * \param character to send
 */
void comSend(const char data);

#endif
