#include <math.h>
#include <stdbool.h>
#include <stdio.h>
#include <unistd.h>

#include "coord.h"

polar_t cart2polar(double x, double y){
	polar_t out;
	out.p = sqrt(x*x + y*y);
	out.phi = out.p == 0 ? 0 : (acos(fmax(fmin(x / out.p, 1), -1)) * (y / out.p < 0 ? -1 : 1));

	return out;
}

cart_t polar2cart(double p, radian_t phi){
	cart_t out;
	out.x = p * cos(phi);
	out.y = p * sin(phi);
	return out;

}

degree_t rad2deg(radian_t angle){
	return angle * 180.0 / M_PI;
}


radian_t deg2rad(degree_t angle){
	return angle * M_PI / 180.0;
}

radian_t cosangle(double a, double b, double c){
	// cosine formula :
	//			c² = a² + b² - 2 * a * b * cos(gamma)
	// <=>  cos(gamma) = (a² + b² - c²) / (2 * a * b)
	if (a != 0 && b != 0) {
		double cos_gamma = (a*a + b*b - c*c)/(2*a*b);
		if (cos_gamma >= -1 && cos_gamma <= 1)
			return acos(cos_gamma);
	}

	return NAN; // Error
}
