#ifndef COORD_H
#define COORD_H

/*! \brief Angle represented in radians
 */
typedef double radian_t;

/*! \brief Angle represented in degrees
 */
typedef double degree_t;

/*! \brief Polar coordinates
 */
typedef struct {
	double p;     ///< distance to the origin (Z axis)
	radian_t phi; ///< angle from the origin
} polar_t;

/*! \brief Cartesian coordinates
 */
typedef struct {
	double x, y;
} cart_t;


/*** Helper functions ***/

/*! \brief Convert cartesian coordinates to polar ones
 * \param x X position
 * \param y Y position
 * \return polar coordinates of the point
 */
polar_t cart2polar(double x, double y);


/*! \brief Convert polar coordinates to cartesian ones
 * \param p distance to the origin
 * \param phi angle from the origin
 * \return cartesian coordinates of the point
 */
cart_t polar2cart(double p, radian_t phi);

/*! \brief Convert radian to degree
 * \param angle Angle in radian
 * \return Angle in degree
 */
degree_t rad2deg(radian_t angle);

/*! \brief Convert degree to radian
 * \param angle Angle in degree
 * \return Angle in radian
 */
radian_t deg2rad(degree_t angle);

/*! \brief Calculate inner angle of a triangle using the law of cosines
 * \param a length of first side containing the requested angle
 * \param b length of second side containing the requested angle
 * \param c length of opposite side
 * \return angle contained between sides a and b or NAN if error
 */
radian_t cosangle(double a, double b, double c);

#endif
